@@ -16,7 +16,7 @@ router.register(
     'enterprise-learner-enrollment',
 )
 router.register(
-    r'enterprise/(?P<enterprise_id>.+)/learners',
+    r'enterprise/(?P<enterprise_id>.+)/users',
     views.EnterpriseLearnerViewSet,
     'enterprise-learner',
 )
