@@ -81,6 +81,7 @@ class EnterpriseLearnerEnrollment(models.Model):
     unenrollment_end_within_date = models.DateField(null=True)
     is_refunded = models.BooleanField(default=None, null=True)
     seat_delivery_method = models.CharField(max_length=255, null=True)
+    offer_id = models.PositiveIntegerField(null=True)
     offer_name = models.CharField(max_length=255, null=True)
     offer_type = models.CharField(max_length=255, null=True)
     coupon_code = models.CharField(max_length=255, null=True)
@@ -102,6 +103,7 @@ class EnterpriseLearnerEnrollment(models.Model):
     course_primary_subject = models.CharField(max_length=255, null=True)
     has_passed = models.BooleanField(default=False)
     last_activity_date = models.DateField(null=True, db_index=True)
+    total_learning_time_seconds = models.PositiveIntegerField(default=0)
     progress_status = models.CharField(max_length=255, null=True)
     passed_date = models.DateField(null=True)
     current_grade = models.FloatField(null=True)
