@@ -23,22 +23,22 @@ def create_files(files_data):
 
     return files, total_size
 
-def verify_compressed(self, zip_file, files, original_file_size, password):
+def verify_compressed(self, delivery_files, files, original_file_size, password):
     """
     Verify that file is compress correctly.
     """
     # Verify file is compressed.
-    zip_file_size = os.path.getsize(zip_file)
+    zip_file_size = os.path.getsize(delivery_files)
     assert zip_file_size < original_file_size
 
-    zipfile = ZipFile(zip_file, 'r')
+    zipfile = ZipFile(delivery_files, 'r')
 
     for file in files:
         # Verify text file is present in zip file.
         assert file['file'].name.split('/')[-1] in zipfile.namelist()
 
         # Verify file content is readable with correct password.
-        content = zipfile.read(file['file'].name.split('/')[-1], password)
+        content = zipfile.read(file['file'].name.split('/')[-1], bytes(password, 'utf-8'))
         assert len(content) == file['size']
 
         # Also verify file is not accessible with any other passwords i.e wrong passwords.
